View source: R/confidence_intervals.R
| IC_SCR | R Documentation |
Calculates the confidence interval for the seroconversion rate (SCR) using the confidence interval of seroprevalence.
IC_SCR(SP_interval, SRR, ages, A_max, limits = c(0, 1))
SP_interval |
A vector with the lower and upper limits of seroprevalence. |
SRR |
Seroreversion rate. |
ages |
Vector with the proportions of different ages in the population (age structure). |
A_max |
Maximum age considered in the population. |
limits |
Lower and upper limits for the calculation of |
A vector with the lower and upper limits for the seroconversion rate SCR.
A_max <- 80
age_distribution <- rep(1 / A_max, A_max)
IC_SCR(c(0.1, 0.2), 0.01, age_distribution, A_max, limits = c(0, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.