View source: R/confidence_intervals.R
| IC_SP | R Documentation |
Calculates the confidence interval for a seroprevalence estimate with a specified confidence level.
IC_SP(SP, n, conf.level = 0.95, method = "asymptotic")
SP |
Seroprevalence estimate. |
n |
Sample size. |
conf.level |
Confidence level (default is 0.95). |
method |
Method for calculating the confidence interval (default is "asymptotic"). Available methods: c("asymptotic","exact","ac","wilson","logit","cloglog") |
A vector with the lower and upper limits of the confidence interval.
The methods available in this function are some of the available in the binom package. For more information, see https://CRAN.R-project.org/package=binom
IC_SP(0.25, 100, conf.level = 0.95, method = "asymptotic")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.