IC_SP_Waldcc: Confidence Interval for Seroprevalence with Continuity...

View source: R/confidence_intervals.R

IC_SP_WaldccR Documentation

Confidence Interval for Seroprevalence with Continuity Correction (Wald Method)

Description

Calculates the confidence interval for seroprevalence using the Wald method with continuity correction.

Usage

IC_SP_Waldcc(SP, n, conf.level = 0.95)

Arguments

SP

Seroprevalence estimate.

n

Sample size.

conf.level

Confidence level (default is 0.95).

Value

A vector with the lower and upper limits of the confidence interval.

Examples

IC_SP_Waldcc(0.25, 100, conf.level = 0.95)

RCMsize documentation built on April 11, 2025, 6:17 p.m.