View source: R/seroprevalence.R
| prob_seropositive | R Documentation |
This function calculates the probability of seropositivity based on the age and the seroconversion and seroreversion rates, using a reversible catalytic model.
prob_seropositive(SCR, SRR, t)
SCR |
Seroconversion Rate |
SRR |
Seroreversion Rate. |
t |
Age for which we want to calculate the probability of seropositivity. |
The probability of seropositivity for age 't'.
For more information on the reversible catalytic model, see https://link.springer.com/article/10.1186/s12936-015-0661-z
prob_seropositive(0.03, 0.01, 45)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.