View source: R/seroprevalence.R
| seroprevalence | R Documentation |
Calculates the seroprevalence considering an age distribution and a reversible catalytic model.
seroprevalence(ages, A_max, SCR, SRR)
ages |
Vector with the proportions of different ages in the population (age structure). |
A_max |
Maximum age considered in the population. |
SCR |
Seroconversion rate. |
SRR |
Seroreversion rate. |
The total seroprevalence weighted by the age distribution.
A_max <- 80
age_distribution <- rep(1 / A_max, A_max)
seroprevalence(age_distribution, A_max, 0.03, 0.01)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.