View source: R/confidence_intervals.R
| IC_SP_Waldcc | R Documentation |
Calculates the confidence interval for seroprevalence using the Wald method with continuity correction.
IC_SP_Waldcc(SP, n, conf.level = 0.95)
SP |
Seroprevalence estimate. |
n |
Sample size. |
conf.level |
Confidence level (default is 0.95). |
A vector with the lower and upper limits of the confidence interval.
IC_SP_Waldcc(0.25, 100, conf.level = 0.95)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.