Learn R Programming

RCMsize (version 1.0.1)

IC_SP_Waldcc: Confidence Interval for Seroprevalence with Continuity Correction (Wald Method)

Description

Calculates the confidence interval for seroprevalence using the Wald method with continuity correction.

Usage

IC_SP_Waldcc(SP, n, conf.level = 0.95)

Value

A vector with the lower and upper limits of the confidence interval.

Arguments

SP

Seroprevalence estimate.

n

Sample size.

conf.level

Confidence level (default is 0.95).

Examples

Run this code
IC_SP_Waldcc(0.25, 100, conf.level = 0.95)

Run the code above in your browser using DataLab