powered by
Calculates the confidence interval for seroprevalence using the Wald method with continuity correction.
IC_SP_Waldcc(SP, n, conf.level = 0.95)
A vector with the lower and upper limits of the confidence interval.
Seroprevalence estimate.
Sample size.
Confidence level (default is 0.95).
IC_SP_Waldcc(0.25, 100, conf.level = 0.95)
Run the code above in your browser using DataLab