Learn R Programming

RCMsize (version 1.0.1)

prob_seropositive: Calculation of Seropositivity Probability

Description

This function calculates the probability of seropositivity based on the age and the seroconversion and seroreversion rates, using a reversible catalytic model.

Usage

prob_seropositive(SCR, SRR, t)

Value

The probability of seropositivity for age `t`.

Arguments

SCR

Seroconversion Rate

SRR

Seroreversion Rate.

t

Age for which we want to calculate the probability of seropositivity.

References

For more information on the reversible catalytic model, see https://link.springer.com/article/10.1186/s12936-015-0661-z

Examples

Run this code
prob_seropositive(0.03, 0.01, 45)

Run the code above in your browser using DataLab