prob_seropositive: Calculation of Seropositivity Probability
Description
This function calculates the probability of seropositivity based on the age and the seroconversion and seroreversion rates,
using a reversible catalytic model.
Usage
prob_seropositive(SCR, SRR, t)
Value
The probability of seropositivity for age `t`.
Arguments
SCR
Seroconversion Rate
SRR
Seroreversion Rate.
t
Age for which we want to calculate the probability of seropositivity.