powered by
Calculates the seroprevalence considering an age distribution and a reversible catalytic model.
seroprevalence(ages, A_max, SCR, SRR)
The total seroprevalence weighted by the age distribution.
Vector with the proportions of different ages in the population (age structure).
Maximum age considered in the population.
Seroconversion rate.
Seroreversion rate.
A_max <- 80 age_distribution <- rep(1 / A_max, A_max) seroprevalence(age_distribution, A_max, 0.03, 0.01)
Run the code above in your browser using DataLab